@@ -6,7 +6,10 @@ class BartApi():
     self.api_key = api_key
 
   def parse_response(self,raw_xml):
-    parsed_xml = etree.parse(raw_xml)
+    if isinstance(raw_xml, bytes):
+      parsed_xml = etree.fromstring(raw_xml, parser=etree.XMLParser(encoding='utf-8'))
+    else:
+      parsed_xml = etree.parse(raw_xml)
     return parsed_xml
 
   def number_of_trains(self):
@@ -20,12 +23,12 @@ class BartApi():
     url = "http://api.bart.gov/api/bsa.aspx?cmd=elev&key=%s" % (self.api_key)
     raw_response = urllib.request.urlopen(url)
     xml = self.parse_response(raw_response)
-    train_count = xml.xpath('bsa')[0].xpath('description')[0].text
-    return train_count
+    elevator_status = xml.xpath('bsa')[0].xpath('description')[0].text
+    return elevator_status
 
   def update_station_list(self):
     url = "http://api.bart.gov/api/stn.aspx?cmd=stns&key=%s" % (self.api_key)
     raw_response = urllib.request.urlopen(url)
     xml = self.parse_response(raw_response)
     with open('station_list.xml', 'w') as f:
-      f.write(etree.tostring(xml))
+      f.write(str(etree.tostring(xml)))
