@@ -1,7 +1,7 @@
 import unittest
 from unittest.mock import patch, Mock
 from bart_api import BartApi
-import os
+import io
 
 class TestBartApi(unittest.TestCase):
 
@@ -17,14 +17,14 @@ class TestBartApi(unittest.TestCase):
   def test_number_of_trains(self,mock_urlopen):
     a = Mock()
     with open('bart_api/test/mocks/train_count.xml') as f:
-      raw_xml = f.read().encode('utf-8')
-    mock_urlopen.return_value = raw_xml
-    expected=51
+      raw_xml = f.read()
+    mock_urlopen.return_value = raw_xml.encode('utf-8')
+    expected=str(51)
     actual = self.bart.number_of_trains()
     self.assertEqual(expected, actual)
-  
+
   @patch('bart_api.urllib.request.urlopen')
-  def test_number_of_trains(self,mock_urlopen):
+  def test_elevator_status(self,mock_urlopen):
     a = Mock()
     with open('bart_api/test/mocks/elev.xml') as f:
       raw_xml = f.read().encode('utf-8')
@@ -32,6 +32,6 @@ class TestBartApi(unittest.TestCase):
     expected=" Attention passengers: All elevators are in service. Thank You. "
     actual = self.bart.elevator_status()
     self.assertEqual(expected, actual)
-
+  
 if __name__ == '__main__':
   unittest.main()
